@@ -11,14 +11,14 @@ import warnings
 import logging
 import getpass
 import datetime
-from tools.geom_dtf import feature_id, geom_prop, mask_layers
-from readers.read_scc_db import read_scc_db
-from readers.get_files import database
-from readers.parse_config import parse_config
-from export.export_nc import export_nc, nc_name
-from export.update_scc_db import update
-from readers.read_config import config
-from debug import log_pack
+from .tools.geom_dtf import feature_id, geom_prop, mask_layers
+from .readers.read_scc_db import read_scc_db
+from .readers.get_files import database
+from .readers.parse_config import parse_config
+from .export.export_nc import export_nc, nc_name
+from .export.update_scc_db import update
+from .readers.read_config import config
+from .debug import log_pack
 
 logger = logging.getLogger(__name__)
 logger = log_pack.scc_logger(logger)
